

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Poppler.Structs.ActionJavascript
    ( 

-- * Exported types
    ActionJavascript(..)                    ,
    newZeroActionJavascript                 ,
    noActionJavascript                      ,


 -- * Properties
-- ** Script
    actionJavascriptReadScript              ,


-- ** Title
    actionJavascriptReadTitle               ,


-- ** Type
    actionJavascriptReadType                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype ActionJavascript = ActionJavascript (ForeignPtr ActionJavascript)
-- | Construct a `ActionJavascript` struct initialized to zero.
newZeroActionJavascript :: MonadIO m => m ActionJavascript
newZeroActionJavascript = liftIO $ callocBytes 24 >>= wrapPtr ActionJavascript

noActionJavascript :: Maybe ActionJavascript
noActionJavascript = Nothing

actionJavascriptReadType :: ActionJavascript -> IO ActionType
actionJavascriptReadType s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

actionJavascriptReadTitle :: ActionJavascript -> IO T.Text
actionJavascriptReadTitle s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO CString
    val' <- cstringToText val
    return val'

actionJavascriptReadScript :: ActionJavascript -> IO T.Text
actionJavascriptReadScript s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO CString
    val' <- cstringToText val
    return val'

type family ResolveActionJavascriptMethod (t :: Symbol) (o :: *) :: * where
    ResolveActionJavascriptMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveActionJavascriptMethod t ActionJavascript, MethodInfo info ActionJavascript p) => IsLabelProxy t (ActionJavascript -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveActionJavascriptMethod t ActionJavascript, MethodInfo info ActionJavascript p) => IsLabel t (ActionJavascript -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


