

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

Action to perform over a list of layers
-}

module GI.Poppler.Structs.ActionLayer
    ( 

-- * Exported types
    ActionLayer(..)                         ,
    newZeroActionLayer                      ,
    noActionLayer                           ,


 -- * Properties
-- ** Action
    actionLayerReadAction                   ,


-- ** Layers
    actionLayerReadLayers                   ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype ActionLayer = ActionLayer (ForeignPtr ActionLayer)
-- | Construct a `ActionLayer` struct initialized to zero.
newZeroActionLayer :: MonadIO m => m ActionLayer
newZeroActionLayer = liftIO $ callocBytes 16 >>= wrapPtr ActionLayer

noActionLayer :: Maybe ActionLayer
noActionLayer = Nothing

actionLayerReadAction :: ActionLayer -> IO ActionLayerAction
actionLayerReadAction s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

actionLayerReadLayers :: ActionLayer -> IO ([Ptr ()])
actionLayerReadLayers s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO (Ptr (GList (Ptr ())))
    val' <- unpackGList val
    return val'

type family ResolveActionLayerMethod (t :: Symbol) (o :: *) :: * where
    ResolveActionLayerMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveActionLayerMethod t ActionLayer, MethodInfo info ActionLayer p) => IsLabelProxy t (ActionLayer -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveActionLayerMethod t ActionLayer, MethodInfo info ActionLayer p) => IsLabel t (ActionLayer -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


