

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Poppler.Structs.ActionRendition
    ( 

-- * Exported types
    ActionRendition(..)                     ,
    newZeroActionRendition                  ,
    noActionRendition                       ,


 -- * Properties
-- ** Media
    actionRenditionReadMedia                ,


-- ** Op
    actionRenditionReadOp                   ,


-- ** Title
    actionRenditionReadTitle                ,


-- ** Type
    actionRenditionReadType                 ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype ActionRendition = ActionRendition (ForeignPtr ActionRendition)
-- | Construct a `ActionRendition` struct initialized to zero.
newZeroActionRendition :: MonadIO m => m ActionRendition
newZeroActionRendition = liftIO $ callocBytes 32 >>= wrapPtr ActionRendition

noActionRendition :: Maybe ActionRendition
noActionRendition = Nothing

actionRenditionReadType :: ActionRendition -> IO ActionType
actionRenditionReadType s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

actionRenditionReadTitle :: ActionRendition -> IO T.Text
actionRenditionReadTitle s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO CString
    val' <- cstringToText val
    return val'

actionRenditionReadOp :: ActionRendition -> IO Int32
actionRenditionReadOp s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO Int32
    return val

actionRenditionReadMedia :: ActionRendition -> IO Media
actionRenditionReadMedia s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 24) :: IO (Ptr Media)
    val' <- (newObject Media) val
    return val'

type family ResolveActionRenditionMethod (t :: Symbol) (o :: *) :: * where
    ResolveActionRenditionMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveActionRenditionMethod t ActionRendition, MethodInfo info ActionRendition p) => IsLabelProxy t (ActionRendition -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveActionRenditionMethod t ActionRendition, MethodInfo info ActionRendition p) => IsLabel t (ActionRendition -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


