

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

A #PopplerQuadrilateral is used to describe rectangle-like polygon
 with arbitrary inclination on a page.

 Since: 0.26
-}

module GI.Poppler.Structs.Quadrilateral
    ( 

-- * Exported types
    Quadrilateral(..)                       ,
    newZeroQuadrilateral                    ,
    noQuadrilateral                         ,


 -- * Methods
-- ** quadrilateralCopy
    QuadrilateralCopyMethodInfo             ,
    quadrilateralCopy                       ,


-- ** quadrilateralFree
    QuadrilateralFreeMethodInfo             ,
    quadrilateralFree                       ,


-- ** quadrilateralNew
    quadrilateralNew                        ,




 -- * Properties
-- ** P1
    quadrilateralReadP1                     ,


-- ** P2
    quadrilateralReadP2                     ,


-- ** P3
    quadrilateralReadP3                     ,


-- ** P4
    quadrilateralReadP4                     ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype Quadrilateral = Quadrilateral (ForeignPtr Quadrilateral)
foreign import ccall "poppler_quadrilateral_get_type" c_poppler_quadrilateral_get_type :: 
    IO GType

instance BoxedObject Quadrilateral where
    boxedType _ = c_poppler_quadrilateral_get_type

-- | Construct a `Quadrilateral` struct initialized to zero.
newZeroQuadrilateral :: MonadIO m => m Quadrilateral
newZeroQuadrilateral = liftIO $ callocBoxedBytes 64 >>= wrapBoxed Quadrilateral

noQuadrilateral :: Maybe Quadrilateral
noQuadrilateral = Nothing

quadrilateralReadP1 :: Quadrilateral -> IO Point
quadrilateralReadP1 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO (Ptr Point)
    val' <- (newBoxed Point) val
    return val'

quadrilateralReadP2 :: Quadrilateral -> IO Point
quadrilateralReadP2 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO (Ptr Point)
    val' <- (newBoxed Point) val
    return val'

quadrilateralReadP3 :: Quadrilateral -> IO Point
quadrilateralReadP3 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 32) :: IO (Ptr Point)
    val' <- (newBoxed Point) val
    return val'

quadrilateralReadP4 :: Quadrilateral -> IO Point
quadrilateralReadP4 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 48) :: IO (Ptr Point)
    val' <- (newBoxed Point) val
    return val'

-- method Quadrilateral::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- returnType : TInterface "Poppler" "Quadrilateral"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_quadrilateral_new" poppler_quadrilateral_new :: 
    IO (Ptr Quadrilateral)


quadrilateralNew ::
    (MonadIO m) =>
    m Quadrilateral                         -- result
quadrilateralNew  = liftIO $ do
    result <- poppler_quadrilateral_new
    checkUnexpectedReturnNULL "poppler_quadrilateral_new" result
    result' <- (wrapBoxed Quadrilateral) result
    return result'

-- method Quadrilateral::copy
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Poppler" "Quadrilateral", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TInterface "Poppler" "Quadrilateral"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_quadrilateral_copy" poppler_quadrilateral_copy :: 
    Ptr Quadrilateral ->                    -- _obj : TInterface "Poppler" "Quadrilateral"
    IO (Ptr Quadrilateral)


quadrilateralCopy ::
    (MonadIO m) =>
    Quadrilateral                           -- _obj
    -> m Quadrilateral                      -- result
quadrilateralCopy _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    result <- poppler_quadrilateral_copy _obj'
    checkUnexpectedReturnNULL "poppler_quadrilateral_copy" result
    result' <- (wrapBoxed Quadrilateral) result
    touchManagedPtr _obj
    return result'

data QuadrilateralCopyMethodInfo
instance (signature ~ (m Quadrilateral), MonadIO m) => MethodInfo QuadrilateralCopyMethodInfo Quadrilateral signature where
    overloadedMethod _ = quadrilateralCopy

-- method Quadrilateral::free
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Poppler" "Quadrilateral", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "poppler_quadrilateral_free" poppler_quadrilateral_free :: 
    Ptr Quadrilateral ->                    -- _obj : TInterface "Poppler" "Quadrilateral"
    IO ()


quadrilateralFree ::
    (MonadIO m) =>
    Quadrilateral                           -- _obj
    -> m ()                                 -- result
quadrilateralFree _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    poppler_quadrilateral_free _obj'
    touchManagedPtr _obj
    return ()

data QuadrilateralFreeMethodInfo
instance (signature ~ (m ()), MonadIO m) => MethodInfo QuadrilateralFreeMethodInfo Quadrilateral signature where
    overloadedMethod _ = quadrilateralFree

type family ResolveQuadrilateralMethod (t :: Symbol) (o :: *) :: * where
    ResolveQuadrilateralMethod "copy" o = QuadrilateralCopyMethodInfo
    ResolveQuadrilateralMethod "free" o = QuadrilateralFreeMethodInfo
    ResolveQuadrilateralMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveQuadrilateralMethod t Quadrilateral, MethodInfo info Quadrilateral p) => IsLabelProxy t (Quadrilateral -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveQuadrilateralMethod t Quadrilateral, MethodInfo info Quadrilateral p) => IsLabel t (Quadrilateral -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


