

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

A #PopplerRectangle is used to describe
locations on a page and bounding boxes
-}

module GI.Poppler.Structs.Rectangle
    ( 

-- * Exported types
    Rectangle(..)                           ,
    newZeroRectangle                        ,
    noRectangle                             ,


 -- * Methods
-- ** rectangleCopy
    RectangleCopyMethodInfo                 ,
    rectangleCopy                           ,


-- ** rectangleFree
    RectangleFreeMethodInfo                 ,
    rectangleFree                           ,


-- ** rectangleNew
    rectangleNew                            ,




 -- * Properties
-- ** X1
    rectangleReadX1                         ,


-- ** X2
    rectangleReadX2                         ,


-- ** Y1
    rectangleReadY1                         ,


-- ** Y2
    rectangleReadY2                         ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype Rectangle = Rectangle (ForeignPtr Rectangle)
foreign import ccall "poppler_rectangle_get_type" c_poppler_rectangle_get_type :: 
    IO GType

instance BoxedObject Rectangle where
    boxedType _ = c_poppler_rectangle_get_type

-- | Construct a `Rectangle` struct initialized to zero.
newZeroRectangle :: MonadIO m => m Rectangle
newZeroRectangle = liftIO $ callocBoxedBytes 32 >>= wrapBoxed Rectangle

noRectangle :: Maybe Rectangle
noRectangle = Nothing

rectangleReadX1 :: Rectangle -> IO Double
rectangleReadX1 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO CDouble
    let val' = realToFrac val
    return val'

rectangleReadY1 :: Rectangle -> IO Double
rectangleReadY1 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO CDouble
    let val' = realToFrac val
    return val'

rectangleReadX2 :: Rectangle -> IO Double
rectangleReadX2 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO CDouble
    let val' = realToFrac val
    return val'

rectangleReadY2 :: Rectangle -> IO Double
rectangleReadY2 s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 24) :: IO CDouble
    let val' = realToFrac val
    return val'

-- method Rectangle::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- returnType : TInterface "Poppler" "Rectangle"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_rectangle_new" poppler_rectangle_new :: 
    IO (Ptr Rectangle)


rectangleNew ::
    (MonadIO m) =>
    m Rectangle                             -- result
rectangleNew  = liftIO $ do
    result <- poppler_rectangle_new
    checkUnexpectedReturnNULL "poppler_rectangle_new" result
    result' <- (wrapBoxed Rectangle) result
    return result'

-- method Rectangle::copy
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Poppler" "Rectangle", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TInterface "Poppler" "Rectangle"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_rectangle_copy" poppler_rectangle_copy :: 
    Ptr Rectangle ->                        -- _obj : TInterface "Poppler" "Rectangle"
    IO (Ptr Rectangle)


rectangleCopy ::
    (MonadIO m) =>
    Rectangle                               -- _obj
    -> m Rectangle                          -- result
rectangleCopy _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    result <- poppler_rectangle_copy _obj'
    checkUnexpectedReturnNULL "poppler_rectangle_copy" result
    result' <- (wrapBoxed Rectangle) result
    touchManagedPtr _obj
    return result'

data RectangleCopyMethodInfo
instance (signature ~ (m Rectangle), MonadIO m) => MethodInfo RectangleCopyMethodInfo Rectangle signature where
    overloadedMethod _ = rectangleCopy

-- method Rectangle::free
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Poppler" "Rectangle", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "poppler_rectangle_free" poppler_rectangle_free :: 
    Ptr Rectangle ->                        -- _obj : TInterface "Poppler" "Rectangle"
    IO ()


rectangleFree ::
    (MonadIO m) =>
    Rectangle                               -- _obj
    -> m ()                                 -- result
rectangleFree _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    poppler_rectangle_free _obj'
    touchManagedPtr _obj
    return ()

data RectangleFreeMethodInfo
instance (signature ~ (m ()), MonadIO m) => MethodInfo RectangleFreeMethodInfo Rectangle signature where
    overloadedMethod _ = rectangleFree

type family ResolveRectangleMethod (t :: Symbol) (o :: *) :: * where
    ResolveRectangleMethod "copy" o = RectangleCopyMethodInfo
    ResolveRectangleMethod "free" o = RectangleFreeMethodInfo
    ResolveRectangleMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveRectangleMethod t Rectangle, MethodInfo info Rectangle p) => IsLabelProxy t (Rectangle -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveRectangleMethod t Rectangle, MethodInfo info Rectangle p) => IsLabel t (Rectangle -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif


